@@ -2,7 +2,7 @@ package File::FlockDir;
 # File::FlockDir.pm
 
 sub Version { $VERSION; }
-$VERSION = sprintf("%d.%02d", q$Revision: 1.03 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.04 $ =~ /(\d+)\.(\d+)/);
 
 # Copyright (c) 1999, 2000 William Herrera. All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
@@ -42,9 +42,6 @@ use File::LockDir qw(nflock nunflock);
 
 use Carp;
 
-# the module archive File-PathConvert-xxx is on CPAN and may be included with this package
-use File::PathConvert qw(&rel2abs);
-
 # override open to save pathname for the handle
 sub open (*;$) {
     my $fh = shift;
@@ -58,7 +55,10 @@ sub open (*;$) {
     if($retval) {
         $spec =~ /\A[\s+<>]*(\S+)/; 
         if($1) {
-            $handles_to_names{$fh} = rel2abs($1) 
+            my $t = $1;
+            # FATxx File::Basename module file system bug workaround
+            $t =~ s|:[\\/]([^\\/]*\Z)|:/../$1|;        
+            $handles_to_names{$fh} = $t 
                           unless($handles_to_names{$fh});
         }
         else { carp("syntax error in File::FlockDir open for $spec\n"); }
